狮子王 (豆瓣)
Description: 狮子王电影简介和剧情介绍,狮子王影评、图片、预告片、影讯、论坛、在线购票
Keywords: 狮子王,The Lion King,狮子王影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.59豆瓣电影Top250

# 狮子王 The Lion King (1994)

导演: 罗杰·阿勒斯 / 罗伯·明可夫
编剧: 艾琳·梅琪 / 乔纳森·罗伯特 / 琳达·伍尔芙顿
主演: 乔纳森·泰勒·托马斯 / 马修·布罗德里克 / 杰瑞米·艾恩斯 / 詹姆斯·厄尔·琼斯 / 莫伊拉·凯利 / 内森·连恩 / 尼基塔·卡兰姆 / 埃林·萨贝拉 / 乌比·戈德堡 / 罗温·艾金森
类型: 动画 / 歌舞 / 冒险
制片国家/地区: 美国
语言: 英语 / 斯瓦希里语 / 科萨语 / 祖鲁语
上映日期: 1995-07-15(中国大陆) / 1994-06-15(美国) / 2011-09-16(美国)
片长: 89 分钟
又名: 狮子王3D
IMDb: tt0110357
豆瓣评分
引用
9.1
793810人评价
5星
61.0%
4星
32.3%
3星
6.3%
2星
0.3%
1星
0.1%
好于 98% 动画片
好于 98% 冒险片
想看 看过
评价:
推荐

## 狮子王的剧情简介 · · · · · ·

辛巴是狮子王国的小王子，他的父亲穆法沙是一个威严的国王。然而叔叔刀疤却对穆法沙的王位觊觎已久。
要想坐上王位宝座，刀疤必须除去小王子。于是，刀疤利用种种借口让辛巴外出，然后伺机大开杀戒，无奈被穆法沙即时来救。在反复的算计下，穆法沙惨死在刀疤手下，刀疤别有用心的劝辛巴离开，一方面派人将他赶尽杀绝。
辛巴逃亡中遇到了机智的丁满和善良的彭彭，他们抚养辛巴长成雄壮的大狮子，鼓励他回去森林复国。在接下来一场复国救民的斗争中，辛巴真正长成一个坚强的男子汉，领会了责任的真谛。 ©豆瓣

## 狮子王的演职员 · · · · · · ( 全部 43 )

- 罗杰·阿勒斯 导演
- 罗伯·明可夫 导演
- 乔纳森·泰勒·托马斯 配 Young Simba
- 马修·布罗德里克 配 Simba
- 杰瑞米·艾恩斯 配 Scar
- 詹姆斯·厄尔·琼斯 配 Mufasa

## 狮子王的视频和图片 · · · · · · ( 预告片9 | 视频评论1 · 添加 | 图片484 · 添加 )

## 狮子王的获奖情况 · · · · · · ( 全部 )

- 第67届奥斯卡金像奖
- 最佳原创配乐
- 汉斯·季默

- 第52届金球奖
- 电影类 最佳音乐/喜剧片

- 第48届英国电影学院奖
- 电影奖 最佳原创音乐(提名)
- 汉斯·季默

## 喜欢这部电影的人也喜欢 · · · · · ·

  大闹天宫

  天空之城

  哪吒闹海

  幽灵公主

  哈尔的移动城堡

  玩具总动员

  风之谷

  天书奇谭

  冰川时代

  怪兽电力公司

我要写短评

## 狮子王的短评 · · · · · · ( 全部 101046 条 )

热门 / 最新 / 好友

### 1179 有用 罗弘霉素 看过 2010-07-08 18:09:30

败在“刀疤”没有反派魅力！

### 2146 有用 影志 看过 2005-08-24 07:19:46

“太阳所能照到的地方，都是我们的国土” 随时随地、再看百遍、都会感动如初的经典。

### 1786 有用 恶魔的步调 看过 2006-05-13 08:01:49

hakunamatata

### 444 有用 同志亦凡人中文站 看过 2012-10-28 18:47:54

现在看剧情真的好简单啊，不过拟人感实在太完美了。还有那个“哈库那莫塔塔”，好多年没听到了...Can You Feel My Love Tonight？

### 548 有用 铃铛 看过 2018-04-25 16:06:49

我只是在必要的时候才会勇敢，勇敢并不代表你要到处闯祸。

> 更多短评 101046条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 狮子王的影评 · · · · · · ( 全部 601 条 )

热门 / 最新 / 好友
五乔 2014-04-25 09:00:37

## 多数现代人对《哈姆雷特》的理解，也就是《狮子王》了吧

1989至1999的十年，被称作迪士尼的“文艺复兴”时期，这一时期的迪士尼不仅走出了之前的票房阴霾，更重要的是复兴了迪士尼本人对动画长片的理解：动画电影不仅仅是拍给小孩子看的作品、而应当同样适合成年人欣赏。1994年上映的《狮子王》可以说是迪士尼史上最严肃的作品。剥去... (展开)
782 20 53回应 收起
黑左。 2005-10-26 16:05:21

## 没有the lion king，我的生活会是另一样

这样说吧 没有lion king 我就不会去买电影的ost 没买这部ost 我就不会收藏Disney的所有ost 没有收藏disney的ost 我就不会留意所有主题曲的歌手 也就不会去买Elton John\Cline Dion\John Secada的唱片 也就不会接触欧美流行 也就不会上摇滚的贼船 也就不会知道音乐是一门艺术 也... (展开)
682 88 111回应 收起
FF 2011-09-18 18:52:38

## Long live the king

什么3D重制、什么特别展映，其实都只是迪斯尼时隔十七年之后老片回笼再骗钱的手段而已。效果如何？Damn it，everybody's so friggin' happy. 今天去看的是五点半的那场，结果AMC最大的一个厅基本坐满。“It's a small world after all”: 有白发苍苍的老人，有手牵着手的年轻... (展开)
453 17 40回应 收起
痞子笛🌈 2005-07-25 11:23:29

## 最喜欢的一个画面

就是木法沙站在吉祥石上很威严的看着脚下的王国，这时候乌鸦飞过来向他请安，他温暖的向乌鸦点头。 我一直认为这是一个男人最温情的时刻 (展开)
245 13 47回应 收起
时间地理学家 2011-09-23 12:50:06

## 狮子王3D：不是去欣赏一场电影，而是去寻找一段回忆

1995年，我10岁，上小学三年级，当上了班里唯一的大队委，爱好是集邮，打乒乓球，画画和看动画片。 那个时候成都的交通还很通畅，大人们骑着自行车在都市的逆流里通勤；钟水饺还五毛钱一碗，没有各色诡异的配餐；劣质服装的集散地不是九龙广场而是商业场，穿过低矮阴湿的隧道... (展开)
113 4 14回应 收起
芝麻蛋老妈 2017-06-14 00:15:13

## 儿时美好的回忆

满满的感动，想起小时候租碟看，一晃这么多年过去了！ 以前我们玩耍，觉得最洋气的就是！！几个小朋友！！一起坐着一个小板凳看着狮子王！！辛巴和梅花鹿！还有好多伙伴们！一起战斗的场景！友谊！！ 以后最想让孩子看的动画片就是狮子王！！也可以让他学到，任何事情，属于... (展开)
51 2 2回应 收起
沙与鸟 2018-05-17 08:10:34

## 一部伴随人成长的电影

《狮子王》是一部可以伴随着人成长的电影，它给人带来的感动，回味是深刻而长久的。第一次看它就哭了两次，一次是穆法沙死去辛巴绝望的呼喊，一次是影片结尾辛巴重新站在荣耀岩上，万物复苏。 故事的背景选在了充满生命力的非洲大草原上，壮美的草原把爱、责任、成长、生命轮回... (展开)
66 1 1回应 收起
沙恭达罗 2005-11-02 23:31:53

## LOVE, RESPONSIBILITY

还记得在LOIN KING的原声带的第一页写着,LOVE, RESPOSIBILITY,KNOWING WHO YOU ARE AND TAKING YOUR PALCE IN THE CIRCLE OF LIFE. 很多年过去了,我还清楚的记得那些字圆润的字体和作为背景的乞立马扎罗山白雪皑皑的山峰．这几句话让感动至今．很喜欢看到辛巴慢慢的登上荣耀石... (展开)
57 3 10回应 收起
不要不开心哦 2017-05-07 19:52:30

## 关于《狮子王》自身的魅力与人性问题的思考

这篇影评可能有剧透

在动画的历史上，《狮子王》堪称一部史诗巨作，它的一切所带给我的思考是难以忘怀与忽略的。《狮子王》1994年6月24日在美国上映，以其活泼可爱的卡通形象、震撼人心的壮丽场景、感人至深的优美音乐，以及其所描述的爱情与责任的故事内容，深深的打动了许多人。该电影不仅创造了... (展开)
37 2 2回应 收起
油爆枇杷拌着面 2018-03-07 22:46:05

## KING and CROWN

这篇影评可能有剧透

“欲戴王冠，必承其重” 当王子的复仇记《哈姆雷特》用另一个方式打开时，别有一番韵味。 最喜欢的还是那句“阳光能照到的地方，都是我们的国土。”自信又尊重每一个生命的木法沙，是辛巴成长的榜样。 很喜欢木法沙对鸟儿说的早安，很喜欢彭彭和丁满的无厘头，很喜欢辛巴慢慢的... (展开)
43 1回应 收起

> 更多影评 601篇

添加新讨论

## 讨论区 · · · · · ·

和儿子一起看过的动画片 | 来自燕子 |  | 2022-11-24 09:21:41
还以为狮子王剽窃《森林大帝》是人尽皆知的事实 | 来自追杀美少女 | 2 回应 | 2022-11-06 16:36:28
好多年 | 来自曾丕岩 |  | 2022-10-29 22:09:39
狮子王 | 来自砚之 |  | 2022-10-10 19:38:39
求个百度网盘资源 | 来自Nur |  | 2022-10-02 08:41:22

> 去这部影片的讨论区（全部169条）

## 关于《狮子王》的问题 · · · · · · ( 全部5个 )

- 看了动物城，我新编了一部狮子王，十分你们给我几分？ 3人回答
- 丁满堵住猪嘴到底是隐瞒什么？ 1人回答

> 全部5个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- 【豆瓣高分动画长片】 (影志)
- 80末出生的人是这样成长的 (沉歌)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- momo
  4分钟前 看过
- 锦
  5分钟前 看过
- 趋丞
  12分钟前 看过

1559646人看过 / 169372人想看

订阅狮子王的评论:
feed: rss 2.0